
/* Generated data (by glib-mkenums) */

#ifndef GSPELL_ENUM_TYPES_H
#define GSPELL_ENUM_TYPES_H

#if !defined (GSPELL_H_INSIDE) && !defined (GSPELL_COMPILATION)
#error "Only <gspell/gspell.h> can be included directly."
#endif

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "gspell-checker.h" */

#define GSPELL_TYPE_CHECKER_ERROR (gspell_checker_error_get_type())
GType gspell_checker_error_get_type (void);

G_END_DECLS

#endif /* GSPELL_ENUM_TYPES_H */

/* Generated data ends here */

